==> order-center-domain-3.0.0-CLOUD-DEV-20250409.072946-169-sources.jar: com/tydic/dyc/oc/model/order/sub/UocConfTabOrdState.java <==
package com.tydic.dyc.oc.model.order.sub;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;

/**
 * 标题:UocConfTabOrdState
 * 说明:页面订单状态映射规则配置主体
 * 时间:2022-03-11 09:40
 * 作者:TKL
 **/
@Data
public class UocConfTabOrdState implements Serializable {
	private static final long serialVersionUID = -923711013281449615L;

	@DocField(value = "id")
	private Long id;

	@DocField(value = "tab标签id")
	private Integer tabId;

	@DocField(value = "tab标签名称")
	private String tabName;

	@DocField(value = "顺序")
	private Integer sort;

	@DocField(value = "单据类型             1订单             2.销售单             3 发货单             4.收货单             5.售后服务单             6.支付单                          99.其他")
	private Integer objType;

	@DocField(value = "字典编码")
	private String pCode;

	@DocField(value = "订单状态编码")
	private String orderStatusCode;

	@DocField(value = "订单状态说明")
	private String orderStatusName;

	@DocField(value = "子环节订单状态编码，逗号分隔")
	private String subOrderStatusCode;

	@DocField(value = "子环节订单状态说明")
	private String subOrderStatusName;

	@DocField(value = "单据状态")
	private String orderStatus;

	@DocField(value = "订单来源             1 专区             2 电子超市             3 框架协议             4 一单一采                          10 店铺下单             20 app下单")
	private String orderSource;

	@DocField(value = "订单来源名称")
	private String orderSourceName;

	@DocField(value = "订单系统")
	private String orderSystem;

	@DocField(value = "订单系统名称")
	private String orderSystemName;

	@DocField(value = "索引名")
	private String indexName;

		@DocField(value = "排序")
	private String orderBy;

	@DocField(value = "租户id")
	private Long sysTenantId;

	@DocField(value = "租户名称")
	private String sysTenantName;

	@DocField("菜单编码")
	private String menuCode;

	@DocField(value = "已办任务环节编码")
	private String doneTacheCode;

	@DocField(value = "参数JSON串")
	private String paramJson;
}

==> order-center-domain-3.1.0-CLOUD-DEV-20230625.084845-58-sources.jar: com/tydic/dyc/oc/model/order/sub/UocConfTabOrdState.java <==
package com.tydic.dyc.oc.model.order.sub;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;

/**
 * 标题:UocConfTabOrdState
 * 说明:页面订单状态映射规则配置主体
 * 时间:2022-03-11 09:40
 * 作者:TKL
 **/
@Data
@EqualsAndHashCode(callSuper=false)
public class UocConfTabOrdState implements Serializable {
	private static final long serialVersionUID = -923711013281449615L;

	@DocField(value = "id")
	private Long id;

	@DocField(value = "tab标签id")
	private Integer tabId;

	@DocField(value = "tab标签名称")
	private String tabName;

	@DocField(value = "顺序")
	private Integer sort;

	@DocField(value = "单据类型             1订单             2.销售单             3 发货单             4.收货单             5.售后服务单             6.支付单                          99.其他")
	private Integer objType;

	@DocField(value = "字典编码")
	private String pCode;

	@DocField(value = "订单状态编码")
	private String orderStatusCode;

	@DocField(value = "订单状态说明")
	private String orderStatusName;

	@DocField(value = "子环节订单状态编码，逗号分隔")
	private String subOrderStatusCode;

	@DocField(value = "子环节订单状态说明")
	private String subOrderStatusName;

	@DocField(value = "单据状态")
	private String orderStatus;

	@DocField(value = "订单来源             1 专区             2 电子超市             3 框架协议             4 一单一采                          10 店铺下单             20 app下单")
	private String orderSource;

	@DocField(value = "订单来源名称")
	private String orderSourceName;

	@DocField(value = "订单系统")
	private String orderSystem;

	@DocField(value = "订单系统名称")
	private String orderSystemName;

	@DocField(value = "索引名")
	private String indexName;

	@DocField(value = "排序")
	private String orderBy;

	@DocField("菜单编码")
	private String menuCode;

	@DocField(value = "已办任务环节编码")
	private String doneTacheCode;

	@DocField(value = "参数JSON串")
	private String paramJson;
}
